==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sl" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+245"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation type="unfinished">Curve on mesh...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation type="unfinished">Curve on mesh</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-191"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Ustvari mrežo iz oblike …</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Teseliraj obliko</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+106"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation type="unfinished">Create section from mesh and plane</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Presek</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Prireži mrežo z ravnino</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Prireže mrežo z ravnino</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Ustvari</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation type="unfinished">Close wire</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Počisti</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Prekliči</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation type="unfinished">Wrong mesh picked</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>Ni izbranih točk</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation type="unfinished">Curve on mesh</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Žica</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation type="unfinished">Snap tolerance to vertexes</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation type="unfinished">Split threshold</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation type="unfinished">Spline Approximation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation type="unfinished">Tolerance to mesh</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Zveznost</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation type="unfinished">Maximum curve degree</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation type="unfinished">Start</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Teselacija</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Oblike</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Možnosti izdelovanja mrež</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>Določi odseke po barvi ploskve</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation>Uporabi barve ploskev za mrežo</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation type="unfinished">Angular deviation:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation type="unfinished">Relative surface deviation</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Največja dolžina roba:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>Drobnatost:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Zelo grobo</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Groba</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Zmerna</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>Drobna</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Zelo fino</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Uporabniško določeno</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Velikost elementov mreže:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Število elementov na rob:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Število elementov na polmer krivulje:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Optimiziraj površino</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Elementi drugega reda</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Prevladujoče štirikotno</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Nastavitve</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Odstopanje površine:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Največja dolžina roba:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+225"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Najprej izberite obliko za pretvorbo v mrežo.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>Ni dokumenta '%1'.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Select plane</source>
      <translation>Izberite ravnino</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Izberite ravnino s katero želite prerezati mrežo.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Select plane</source>
      <translation>Izberite ravnino</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Izberite ravnino, s katero želite prirezati mrežo.</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>Mrežni del</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sl" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+290"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation>Krivulja na mreži...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation>Krivulja na mreži</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-235"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Ustvari mrežo iz oblike …</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Teseliraj obliko</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+150"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>Ustvari prerez iz mreže in ravnine</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Presek</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Prireži mrežo z ravnino</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Prireže mrežo z ravnino</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Ustvari</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation>Zapri žico</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Počisti</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Prekliči</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation>Izbrana je napačna mreža</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>Ni izbranih točk</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation>Krivulja na mreži</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Žica</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation>Pripni toleranco na vozlišče</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation>Prag razdelitve</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation>Aproksimacija črte Spline</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation>Toleranca mreži</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Zveznost</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation>Najvišja stopnja krivulje</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>Začni</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Teselacija</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Oblike</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Možnosti izdelovanja mrež</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>Določi odseke po barvi ploskve</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation>Uporabi barve ploskev za mrežo</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation>Kotno odstopanje:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation>Relativno odstopanje površine</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Največja dolžina roba:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>Drobnatost:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Zelo grobo</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Groba</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Zmerna</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>Drobna</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Zelo fino</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Uporabniško določeno</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Velikost elementov mreže:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Število elementov na rob:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Število elementov na polmer krivulje:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Optimiziraj površino</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Elementi drugega reda</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Prevladujoče štirikotno</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Nastavitve</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Odstopanje površine:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Največja dolžina roba:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+226"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Najprej izberite obliko za pretvorbo v mrežo.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>Ni dokumenta '%1'.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+137"/>
      <source>Select plane</source>
      <translation>Izberite ravnino</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Izberite ravnino s katero želite prerezati mrežo.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Select plane</source>
      <translation>Izberite ravnino</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Izberite ravnino, s katero želite prirezati mrežo.</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Trim by plane</source>
      <translation>Prereži z ravnino</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Select the side you want to keep.</source>
      <translation>Izberi strani katero želiš obdržati.</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Inner</source>
      <translation>Notranji</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Outer</source>
      <translation>Zunanji</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Split</source>
      <translation>Razdeli</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>Mrežni del</translation>
    </message>
  </context>
</TS>
